---
Credits
---

# Maintainer
- Kumar Nityan Suman \<<nityan.suman@gmail.com>\>

# Inspired Work From
- Shankar Rao Pandala \<<shankar.pandala@live.com>\>
- Breno Batista da Silva \<<brenophp@gmail.com>\>
